@@ -1,14 +1,15 @@
 ## File Name: lsem.estimate.R
-## File Version: 1.015
+## File Version: 1.068
 
 # estimate LSEM model
 lsem.estimate <- function( data, moderator, moderator.grid,
         lavmodel, type="LSEM", h=1.1, bw=NULL, residualize=TRUE,
         fit_measures=c("rmsea","cfi","tli","gfi","srmr"), standardized=FALSE,
-        standardized_type="std.all", lavaan_fct="sem", sufficient_statistics=FALSE,
-        use_lavaan_survey=FALSE, pseudo_weights=0, sampling_weights=NULL,
-        loc_linear_smooth=FALSE, est_joint=FALSE, par_invariant=NULL, par_linear=NULL,
-        par_quadratic=NULL,    partable_joint=NULL, se=NULL, kernel="gaussian", eps=1E-8,
+        standardized_type="std.all", lavaan_fct="sem", sufficient_statistics=TRUE,
+        pseudo_weights=0, sampling_weights=NULL,
+        loc_linear_smooth=TRUE, est_joint=FALSE, par_invariant=NULL, par_linear=NULL,
+        par_quadratic=NULL, partable_joint=NULL, pw_linear=1,
+        pw_quadratic=1, pd=TRUE, est_DIF=FALSE, se=NULL, kernel="gaussian", eps=1E-8,
         verbose=TRUE, ... )
 {
     lsem_args <- c(as.list(environment()), list(...))
@@ -16,10 +17,11 @@ lsem.estimate <- function( data, moderator, moderator.grid,
     s1 <- Sys.time()
     lavaan.args <- list(...)
     if (standardized){
-        if ( type=="MGM"){
-            stop("standardized=TRUE cannot be applied for type='MGM'")
+        if ( type=='MGM'){
+            stop('standardized=TRUE cannot be applied for type=\'MGM\'')
         }
     }
+    use_lavaan_survey <- FALSE
 
     #- data cleaning
     data <- as.data.frame(data)
@@ -27,7 +29,8 @@ lsem.estimate <- function( data, moderator, moderator.grid,
     moderator_variable <- data[,moderator]
 
     #- process arguments
-    res <- lsem_estimate_proc_args( lavaan.args=lavaan.args, sufficient_statistics=sufficient_statistics,
+    res <- lsem_estimate_proc_args( lavaan.args=lavaan.args,
+                sufficient_statistics=sufficient_statistics,
                 pseudo_weights=pseudo_weights, lavmodel=lavmodel, data=data,
                 use_lavaan_survey=use_lavaan_survey, est_joint=est_joint,
                 par_invariant=par_invariant, par_linear=par_linear,
@@ -46,7 +49,7 @@ lsem.estimate <- function( data, moderator, moderator.grid,
     pseudo_weights <- res$pseudo_weights
     some_ordinal <- res$some_ordinal
 
-    # group moderator if type="MGM"
+    # group moderator if type='MGM'
     out <- lsem_group_moderator( data=data, type=type, moderator.grid=moderator.grid,
                 moderator=moderator, residualize=residualize, h=h )
     data <- out$data
@@ -54,10 +57,13 @@ lsem.estimate <- function( data, moderator, moderator.grid,
     h <- out$h
     residualize <- out$residualize
     moderator.grid <- out$moderator.grid
+
     # residualize input data
-    out <- lsem_residualize( data=data, moderator=moderator, moderator.grid=moderator.grid,
-                lavmodel=lavmodel, h=h, bw=bw, residualize=residualize, eps=eps, verbose=verbose,
-                sampling_weights=sampling_weights, kernel=kernel, variables_model=variables_model)
+    out <- lsem_residualize( data=data, moderator=moderator,
+                    moderator.grid=moderator.grid, lavmodel=lavmodel, h=h, bw=bw,
+                    residualize=residualize, eps=eps, verbose=verbose,
+                    sampling_weights=sampling_weights, kernel=kernel,
+                    variables_model=variables_model)
     G <- out$G
     data <- out$data
     weights <- out$weights
@@ -81,8 +87,9 @@ lsem.estimate <- function( data, moderator, moderator.grid,
 
     #* fit initial lavaan model
     lavfit <- lsem_fit_initial_model( lavmodel__=lavmodel__,
-                    lavaan_est_fun=lavaan_est_fun, dat=dat, variables_model=variables_model,
-                    sampling_weights=sampling_weights, has_meanstructure=has_meanstructure,
+                    lavaan_est_fun=lavaan_est_fun, dat=dat,
+                    variables_model=variables_model, sampling_weights=sampling_weights,
+                    has_meanstructure=has_meanstructure,
                     sufficient_statistics=sufficient_statistics, est_joint=est_joint,
                     se=se, use_lavaan_survey=use_lavaan_survey, ... )
     nobs <- unlist(lavfit@Data@nobs)
@@ -95,25 +102,32 @@ lsem.estimate <- function( data, moderator, moderator.grid,
     NF <- length(fit_measures)
 
     if (standardized){
-        sol <- sirt_import_lavaan_standardizedSolution( object=lavfit, type=standardized_type)
-        colnames(sol)[ which( colnames(sol)=="est.std" ) ] <- "est"
-        sol$lhs <- paste0( "std__", sol$lhs)
+        sol <- sirt_import_lavaan_standardizedSolution( object=lavfit,
+                            type=standardized_type)
+        colnames(sol)[ which( colnames(sol)=='est.std' ) ] <- 'est'
+        sol$lhs <- paste0( 'std__', sol$lhs)
         pars <- sirt_rbind_fill( x=pars, y=sol )
     }
-    pars <- apply( pars[, c("lhs", "op", "rhs" ) ], 1, FUN=function(ll){
+    pars <- apply( pars[, c('lhs', 'op', 'rhs' ) ], 1, FUN=function(ll){
                         paste0( ll[1], ll[2], ll[3] ) } )
     # fit LSEM for all moderator groups
     out2 <- lsem_fitsem( dat=dat, weights=weights, lavfit=lavfit,
                     fit_measures=fit_measures, NF=NF, G=G, moderator.grid=moderator.grid,
-                    verbose=verbose, pars=pars,    standardized=standardized,
-                    variables_model=variables_model, sufficient_statistics=sufficient_statistics,
-                    lavaan_fct=lavaan_fct, lavmodel=lavmodel, use_lavaan_survey=use_lavaan_survey,
+                    verbose=verbose, pars=pars, standardized=standardized,
+                    variables_model=variables_model,
+                    sufficient_statistics=sufficient_statistics,
+                    lavaan_fct=lavaan_fct, lavmodel=lavmodel,
+                    use_lavaan_survey=use_lavaan_survey,
                     pseudo_weights=pseudo_weights, est_joint=est_joint,
                     par_invariant=par_invariant, par_linear=par_linear,
                     par_quadratic=par_quadratic, partable_joint=partable_joint,
+                    pw_linear=pw_linear, pw_quadratic=pw_quadratic,
                     se=se, moderator_variable=moderator_variable,
-                    loc_linear_smooth=loc_linear_smooth, ... )
-
+                    loc_linear_smooth=loc_linear_smooth, pd=pd,
+                    residualized_intercepts=residualized_intercepts,
+                    has_meanstructure=has_meanstructure, est_DIF=est_DIF,
+                    residualize=residualize, ... )
+    dif_effects <- out2$dif_effects
     parameters <- out2$parameters
     is_meanstructure <- out2$is_meanstructure
     fitstats_joint <- out2$fitstats_joint
@@ -122,21 +136,23 @@ lsem.estimate <- function( data, moderator, moderator.grid,
 
     #**** parameter and fit statistics summary
     parameters_summary <- lsem_parameter_summary( parameters=parameters,
-                                moderator.density=out$moderator.density, verbose=verbose )
+                                moderator.density=out$moderator.density,
+                                verbose=verbose )
     out$moderator.density$Neff <- colSums(weights)
 
     obji0 <- obji <- out$moderator.density
     obji$moderator <- obji$moderator
     obji$wgt <- obji$wgt
     obji$Neff <- obji$Neff
-    dfr <- data.frame( M=colMeans( obji0[,-1] ), SD=apply( obji0[,-1], 2, stats::sd ),
-                        min=apply( obji0[,-1], 2, min ), max=apply( obji0[,-1], 2, max ))
-    dfr0 <- data.frame(M=mean( data[,moderator], na.rm=TRUE ), SD=out$sd.moderator,
-                        min=min( data[, moderator], na.rm=TRUE ),
-                        max=max( data[, moderator], na.rm=TRUE ) )
+    Y <- obji0[,-1]
+    dfr <- data.frame( M=colMeans(Y), SD=apply( Y, 2, stats::sd ),
+                            min=apply( Y, 2, min ), max=apply( Y, 2, max ) )
+    x <- data[,moderator]
+    dfr0 <- data.frame(M=mean( x, na.rm=TRUE ), SD=out$sd.moderator,
+                        min=min( x, na.rm=TRUE ), max=max( x, na.rm=TRUE ) )
     obji <- rbind( dfr0, dfr )
     rownames(obji) <- NULL
-    moderator.stat <- data.frame(variable=c("moderator","wgt", "Neff"), obji )
+    moderator.stat <- data.frame(variable=c('moderator','wgt', 'Neff'), obji )
 
     #-- model parameters
     model_parameters <- setdiff( paste(parameters_summary$par), fit_measures)
@@ -146,25 +162,33 @@ lsem.estimate <- function( data, moderator, moderator.grid,
     time <- s2-s1
     res <- list( parameters=parameters, weights=weights,
                     parameters_summary=parameters_summary,
-                    bw=out$bw, h=h, N=out$N, nobs=nobs, moderator.density=out$moderator.density,
+                    bw=out$bw, h=h, N=out$N, nobs=nobs,
+                    moderator.density=out$moderator.density,
                     moderator.stat=moderator.stat, moderator.grouped=moderator.grouped,
-                    m.moderator=m.moderator, sd.moderator=sd.moderator, moderator=moderator,
-                    moderator.grid=moderator.grid, lavmodel=lavmodel, residualize=residualize,
+                    m.moderator=m.moderator, sd.moderator=sd.moderator,
+                    moderator=moderator, moderator.grid=moderator.grid,
+                    lavmodel=lavmodel, residualize=residualize,
                     data=data, residualized.intercepts=residualized_intercepts,
-                    lavaan.args=lavaan.args, lsem_args=lsem_args, fit_measures=fit_measures,
-                    model_parameters=model_parameters, s1=s1, s2=s2, time=time,
+                    lavaan.args=lavaan.args, lsem_args=lsem_args,
+                    fit_measures=fit_measures, model_parameters=model_parameters,
+                    s1=s1, s2=s2, time=time,
                     standardized=standardized, standardized_type=standardized_type,
                     lavaan_fct=lavaan_fct, use_lavaan_survey=use_lavaan_survey,
                     pseudo_weights=pseudo_weights, use_pseudo_weights=use_pseudo_weights,
                     sufficient_statistics=sufficient_statistics,
-                    variables_ordered=variables_ordered, moderator_variable=moderator_variable,
+                    variables_ordered=variables_ordered,
+                    moderator_variable=moderator_variable,
                     sampling_weights=sampling_weights,
-                    no_sampling_weights=no_sampling_weights, is_meanstructure=is_meanstructure,
-                    par_invariant=par_invariant, par_linear=par_linear, par_quadratic=par_quadratic,
-                    est_joint=est_joint, fitstats_joint=fitstats_joint, partable_joint=partable_joint,
-                    sample_stats=sample_stats, loc_linear_smooth=loc_linear_smooth,
+                    no_sampling_weights=no_sampling_weights,
+                    is_meanstructure=is_meanstructure,
+                    par_invariant=par_invariant, par_linear=par_linear,
+                    par_quadratic=par_quadratic,
+                    est_joint=est_joint, fitstats_joint=fitstats_joint,
+                    partable_joint=partable_joint,
+                    dif_effects=dif_effects, sample_stats=sample_stats,
+                    loc_linear_smooth=loc_linear_smooth,
                     se=se, compute_se=compute_se,
                     class_boot=FALSE, type=type, CALL=CALL )
-    class(res) <- "lsem"
+    class(res) <- 'lsem'
     return(res)
 }
