@@ -1,5 +1,5 @@
 ## File Name: mgsem_proc_model_update_penalties_matrix.R
-## File Version: 0.071
+## File Version: 0.072
 
 mgsem_proc_model_update_penalties_matrix <- function(partable, entries, model)
 {
@@ -7,7 +7,7 @@ mgsem_proc_model_update_penalties_matrix <- function(partable, entries, model)
     ND <- nrow(partable)
     for (entry in entries){
         for (dd in 1:ND){
-            if (partable[dd,"unique"]==1){
+            if (partable[dd,'unique']==1){
                 group <- partable$group[dd]+1
                 type_dd <- paste(partable$type[dd])
                 mat_gg_ee <- model[[group]][[entry]]
