@@ -1,5 +1,5 @@
 ## File Name: mgsem_proc_suffstat.R
-## File Version: 0.097
+## File Version: 0.098
 
 
 mgsem_proc_suffstat <- function(suffstat)
@@ -11,22 +11,22 @@ mgsem_proc_suffstat <- function(suffstat)
         N_group[gg] <- suffstat_gg$N
         # rename entries
         ns_gg <- names(suffstat[[gg]])
-        if( ! ( "M" %in% ns_gg ) ){
+        if( ! ( 'M' %in% ns_gg ) ){
             ind <- min( which( unlist( lapply(suffstat_gg, is.vector) ) ))
-            ns_gg[ind] <- "M"
+            ns_gg[ind] <- 'M'
         }
-        if( ! ( "S" %in% ns_gg ) ){
+        if( ! ( 'S' %in% ns_gg ) ){
             ind <- min( which( unlist( lapply(suffstat_gg, is.matrix) ) ))
-            ns_gg[ind] <- "S"
+            ns_gg[ind] <- 'S'
         }
         names(suffstat_gg) <- ns_gg
         I <- length(suffstat_gg$M)
 
         #*** weights for moment-based estimation
-        if ( ! ( "weights_M" %in% ns_gg ) ){
+        if ( ! ( 'weights_M' %in% ns_gg ) ){
             suffstat_gg$weights_M <- 1+0*suffstat_gg$M
         }
-        if ( ! ( "weights_S" %in% ns_gg ) ){
+        if ( ! ( 'weights_S' %in% ns_gg ) ){
             suffstat_gg$weights_S <- 1+0*suffstat_gg$S
         }
         suffstat_gg$vech_weights_S <- mgsem_vech(x=suffstat_gg$weights_S)
