@@ -1,5 +1,5 @@
 ## File Name: mml_calc_like.R
-## File Version: 0.02
+## File Version: 0.04
 
 
 #-- calculation of the likelihood
@@ -9,7 +9,8 @@ mml_calc_like <- function (dat2, dat2resp, probs, pseudoll=0)
         res <- MML2_CALCPOST_V1( DAT2=dat2, DAT2RESP=dat2resp, PROBS=probs)
     }
     if ( pseudoll==1 ){
-        res <- MML2_CALCPOST_V2( DAT2=dat2, DAT2RESP=dat2resp, PROBS=probs)
+        res <- sirt_rcpp_rasch_mml2_calcpost_pseudoll( DAT2=dat2, DAT2RESP=dat2resp,
+                    PROBS=probs)
     }
     return(res)
 }
