@@ -1,5 +1,5 @@
 ## File Name: stratified.cronbach.alpha.R
-## File Version: 0.251
+## File Version: 0.257
 
 
 # stratified Cronbach's Alpha
@@ -22,7 +22,10 @@ stratified.cronbach.alpha <- function( data, itemstrata=NULL )
     }
     # stratified alpha
     dfr$alpha.stratified <- NA
-    dfr$alpha.stratified[1] <- 1 - sum ( ( 1 -  dfr[ -1, "alpha" ] ) * dfr[ -1, "var.tot" ] ) / dfr[1,"var.tot" ]
+    var_tot <- dfr[ -1, "var.tot" ]
+    dfr_alpha <- dfr[ -1, "alpha" ]
+    # dfr$alpha.stratified[1] <- 1 - sum (( 1 - dfr_alpha )*var_tot ) / var_tot
+    dfr$alpha.stratified[1] <- 1 - sum (( 1 - dfr_alpha )*var_tot ) / dfr[ 1, "var.tot"]
     obji <- dfr
     obji[, -c(1:2)] <- round( obji[,-c(1:2) ], 3 )
     if ( ! stratcomp ){
