@@ -1,8 +1,7 @@
 ## File Name: xxirt_compute_itemprobs.R
-## File Version: 0.19
+## File Version: 0.212
 
 
-##############################################################
 # compute item probabilities
 xxirt_compute_itemprobs <- function( item_list, items, Theta, ncat,
         partable, partable_index, item_index=NULL )
@@ -19,11 +18,12 @@ xxirt_compute_itemprobs <- function( item_list, items, Theta, ncat,
     for (jj in 1:I){
         ii <- item_index[jj]
         item_ii <- item_list[[ii]]
-        par_ii <- partable[ partable_index[[ii]], "value" ]
-        arg_ii <- list( par=par_ii, Theta=Theta, ncat=ncat[ii] )
+        par_ii <- partable[ partable_index[[ii]], 'value' ]
+        ncat_ii <- ncat[ii]
+        arg_ii <- list( par=par_ii, Theta=Theta, ncat=ncat_ii )
         probs_ii <- do.call( item_ii$P, arg_ii )
-        probs[ jj, 1:ncat[ii],] <- t(probs_ii)
+        probs[ jj, 1:ncat_ii,] <- t(probs_ii)
     }
     return(probs)
 }
-#############################################################################
+
