@@ -1,7 +1,6 @@
 ## File Name: xxirt_createThetaDistribution.R
-## File Version: 0.15
+## File Version: 0.161
 
-######################################################################
 xxirt_createThetaDistribution <- function( par, est, P, prior=NULL,
         prior_par1=NULL, prior_par2=NULL )
 {
@@ -13,7 +12,6 @@ xxirt_createThetaDistribution <- function( par, est, P, prior=NULL,
     res$prior <- prior
     res$prior_par1 <- prior_par1
     res$prior_par2 <- prior_par2
-    class(res) <- "ThetaDistribution"
+    class(res) <- 'ThetaDistribution'
     return(res)
 }
-######################################################################
